@@ -22,6 +22,12 @@ def main(args=None):
                         help="web server host, default[0.0.0.0]")
     parser.add_argument("--port", default=8080, type=int,
                         help="web server port, default[8080]")
+    parser.add_argument("--default-route", default="/", type=str,
+                        help="default route if not specified")
+    parser.add_argument("--default-code", default=200, type=int,
+                        help="default response code if not specified")
+    parser.add_argument("--default-body", default="", type=str,
+                        help="default response body if not specified")
     parser.add_argument("--route", action='append', default=[],
                         help='method:route:code:body, eg[--route="GET:/hello:200:hello,pywss"]')
     parser.add_argument("--static", action='append', default=[],
@@ -39,6 +45,12 @@ def main(args=None):
     app = pywss.App()
     app.log.SetLevel(getattr(loggus, args.log_level))
     try:
+        app.any(
+            args.default_route,
+            lambda ctx: print(ctx) or ctx.next(),
+            lambda ctx: ctx.set_status_code(args.default_code) or ctx.next(),
+            lambda ctx: ctx.write(args.default_body) or ctx.next(),
+        )
         for arg in args.route:
             method, route, code, body = arg.split(":", 3)
             getattr(app, method.lower())(route, handler_wrap(int(code), body))
@@ -48,14 +60,13 @@ def main(args=None):
         if not args.debug and args.static and args.web:
             _, route = args.static[0].split(":", 1)
             webbrowser.open(f"http://localhost:{args.port}/{route.strip('/')}")
-        if not args.route and not args.static:
-            app.get("/", lambda ctx: ctx.write("hello, pywss"))
     except:
         app.log.traceback()
         print("---help---")
         parser.print_help()
         return
     if args.debug:
+        app.build()
         app.log.info("debug - not run server")
         return
     app.run(host=args.host, port=args.port)
