@@ -1,10 +1,11 @@
 # coding: utf-8
 from urllib.parse import unquote
+from pywss.constant import *
 
 
 def parse_cookies(headers):
     cookies = {}
-    for value in headers.get("Cookie", "").split(";"):
+    for value in headers.get(HeaderCookie, "").split(";"):
         values = value.strip().split("=", 1)
         if len(values) != 2:
             continue
@@ -53,5 +54,5 @@ def parse_headers(fp):
         lines = str(line, 'iso-8859-1').rstrip("\r\n").split(":", maxsplit=1)
         if len(lines) != 2:
             return headers, f"bad request header {line}"
-        headers[lines[0].strip()] = lines[1].strip()
+        headers[lines[0].strip()] = unquote(lines[1].strip())
     return headers, None
